﻿using UnityEngine;
using System.Collections;

public class Fighter : MonoBehaviour {
	public bool isPlayerCharacter = false;
	public float backwardSpeed = 10.0f;
	public float forwardSpeed = 25.0f;
	public float jumpForce = 75.0f;
	public float airControl = 0.6f;
	//this cooldown begins upon pressing the jump button
	public float jumpThrustDuration = 0.333333f;
	private float jumpTimeRemaining = 0.0f;
	public float fallingSpeed = 30.0f;
	private float floorY = 0.0f;
	//this cooldown begins upon pressing the fireball button
	public float fireballDelay = 0.4f;
	private float fireballCooldown = 0.0f;
	//this cooldown begins upon landing
	public float landingDelay = 0.2f;
	private float landingCooldown = 0.0f;
	//these get assigned in Start(), for control of either player character
	private string horizontalAxis;
	private string verticalAxis;
	private string fireballButton;
	//textures for appearance in-game
	public Texture standTexture;
	// Use this for initialization
	void Start () {
		this.SetUpInitialState();
		string playerSuffix = (this.isPlayerCharacter?"2":"1");
		this.horizontalAxis = "Horizontal" + playerSuffix;
		this.verticalAxis = "Vertical" + playerSuffix;
		this.fireballButton = "Fireball" + playerSuffix;
	}
	
	// Update is called once per frame
	void Update () {
		if(Camera.main.gameObject.GetComponent<GameRules>().status != GameRules.GameStatus.RoundPlaying){
			return;
		}
		this.ProcessFireballInputs();
		this.ProcessMovementInputs();
	}
	
	public void SetUpInitialState() {
		//find where the floor should be.
		this.floorY = -1.0f * (Camera.main.orthographicSize - this.transform.localScale.y/2);
		//calculate initial position
		Vector3 startPos = new Vector3(Camera.main.orthographicSize*2-(this.transform.localScale.x),this.floorY,25.0f);
		//player is always on the left
		if(this.isPlayerCharacter) {
			startPos.x *= -1;
		}
		else {
			//since the other player moves the other way
			float temp = this.forwardSpeed;
			this.forwardSpeed = this.backwardSpeed;
			this.backwardSpeed = temp;
		}
		this.transform.localPosition = startPos;
		//resize character
		Vector3 newScale = this.transform.localScale;
		newScale.y = Camera.main.orthographicSize * 0.75f;
		newScale.x = 0.666f*newScale.y;
		this.transform.localScale = newScale;
		//set texture
		Vector2 textureScale = this.renderer.material.GetTextureScale("_MainTex");
		if(!this.isPlayerCharacter) {
			textureScale.x = 1.0f;
		}
		this.renderer.material.SetTextureScale("_MainTex", textureScale);
	}
	
	private void ProcessMovementInputs() {
		Vector3 newPos = this.transform.localPosition;
		//left movement
		if(Input.GetAxis(this.horizontalAxis) < -0.2f) {
			newPos.x -= (this.backwardSpeed * Time.deltaTime) * ((newPos.y > this.floorY)?this.airControl:1.0f);
		}
		//right movement
		else if(Input.GetAxis(this.horizontalAxis) > 0.2f) {
			newPos.x += (this.forwardSpeed * Time.deltaTime) * ((newPos.y > this.floorY)?this.airControl:1.0f);
		}
		//detect jumping
		if(this.jumpTimeRemaining <= 0.0f && this.landingCooldown <= 0.0f && newPos.y <= this.floorY) {
			if(Input.GetAxis(this.verticalAxis) > 0.2f) {
				this.jumpTimeRemaining = this.jumpThrustDuration;
			}
		}
		//earlier jump's lasting effect
		else if(this.jumpTimeRemaining > 0.0f) {
			newPos.y += this.jumpForce * Time.deltaTime;
			this.jumpTimeRemaining -= Time.deltaTime;
		}
		//falling after a jump
		if(newPos.y > this.floorY){
			newPos.y -= this.fallingSpeed * Time.deltaTime;
			if(newPos.y < this.floorY) {
				newPos.y = this.floorY;
				this.landingCooldown = this.landingDelay;
			}
		}
		if(this.landingCooldown > 0.0f) {
			this.landingCooldown -= Time.deltaTime;
		}
		this.transform.localPosition = newPos;
	}
	private void ProcessFireballInputs() {
		if(this.fireballCooldown <= 0.0f) {
			if(Input.GetButtonDown(this.fireballButton)) {
				this.fireballCooldown = this.fireballDelay;
				GameObject fbObject = GameObject.CreatePrimitive(PrimitiveType.Sphere);
				fbObject.transform.localPosition = this.transform.localPosition;
				Fireball fbComponent = fbObject.AddComponent<Fireball>();
				fbComponent.originator = this;
				if(!this.isPlayerCharacter) {
					fbComponent.speed *= -1;
				}
			}
		}
		else if(this.fireballCooldown > 0.0f) {
			this.fireballCooldown -= Time.deltaTime;
		}
	}
}
