﻿using UnityEngine;
using System.Collections;

public class Fireball : MonoBehaviour {
	public float size = 3.5f;
	public float speed = 35.0f;
	public float lifetime = 1.5f;
	public float offense = 100.0f;
	public Vector3 trajectory;
	public Fighter originator;
	public Material fireballMaterial;
	// Use this for initialization
	void Start () {
		//init size and trajectory
		this.trajectory = new Vector3(1.0f,0.0f,0.0f);
		this.transform.localScale = new Vector3(this.size, this.size, this.size);
		//create collision info
		Rigidbody fbRigidbody = this.gameObject.AddComponent<Rigidbody>();
		fbRigidbody.isKinematic = true;
		this.gameObject.collider.isTrigger = true;
		// and some hit points!
		Damageable d = this.gameObject.AddComponent<Damageable>();
		d.vitality = 20.0f;
		this.renderer.material = Resources.Load("FireballMaterial") as Material;
	}
	
	// Update is called once per frame
	void Update () {
		Vector3 newPos = this.transform.localPosition;
		newPos.x += this.speed * Time.deltaTime;
		this.transform.localPosition = newPos;
		if(this.lifetime > 0.0f) {
			this.lifetime -= Time.deltaTime;
			if(this.lifetime < 0.0f) {
				Destroy(this.gameObject);
			}
		}
		Vector3 rot = this.gameObject.transform.localRotation.eulerAngles;
		rot.y = rot.y + 25.0f;
		this.gameObject.transform.localRotation = Quaternion.Euler(rot);
	}
	
	void OnTriggerEnter(Collider other) {
		Fireball fb = other.gameObject.GetComponent<Fireball>();
		Fighter victim = other.gameObject.GetComponent<Fighter>();
		//fireballs mutually fizzle
		if(fb) {
			Destroy(this.gameObject);
			Debug.Log("Fireball Collision.");
		}
		//victim Fighters should receive a "hit by fireball" message
		if(victim && this.originator != victim) {
			Damageable victimHP = victim.GetComponent<Damageable>();
			if(victimHP) {
				victimHP.HitByFireball(this);
			}
			Destroy(this.gameObject);
		}
	}
}
