﻿using UnityEngine;
using System.Collections;

public class GameRules : MonoBehaviour {
	public Fighter playerOne;
	public Fighter playerTwo;
	private Damageable p1Damage;
	private Damageable p2Damage;
	private Rect p1HealthRect;
	private Rect p2HealthRect;
	public enum GameStatus {RoundStart, RoundPlaying, RoundOver};
	public GameStatus status = GameStatus.RoundStart;
	public Fighter winner = null;
	// Use this for initialization
	void Start () {
		this.p1HealthRect = new Rect(10.0f, 10.0f, 50.0f, 50.0f);
		this.p2HealthRect = new Rect(Screen.width - 60.0f, 10.0f, 50.0f, 50.0f);
		this.p1Damage = playerOne.gameObject.GetComponent<Damageable>();
		this.p2Damage = playerTwo.gameObject.GetComponent<Damageable>();
		StartCoroutine("BeginGameAfterDelay",2.0f);
	}
	
	// Update is called once per frame
	void Update () {
		if(this.status == GameStatus.RoundPlaying) {
			this.CheckKnockout();
			this.CheckTimeout();
		}
	}
	
	void OnGUI() {
		GUIStyle guiStyle = new GUIStyle();
		guiStyle.fontSize = 32;
		GUI.Box(this.p1HealthRect, this.p1Damage.vitality.ToString(), guiStyle);
		GUI.Box(this.p2HealthRect, this.p2Damage.vitality.ToString(), guiStyle);
	}
	
	private void CheckKnockout() {
		bool p1DidKO = false;
		bool p2DidKO = false;
		if(this.p1Damage.vitality <= 0.0f) {
			p2DidKO = true;
			this.winner = this.playerTwo;
		}
		if(this.p2Damage.vitality <= 0.0f) {
			p1DidKO = true;
			this.winner = this.playerOne;
		}
		if(p1DidKO && p2DidKO) {
			this.winner = null;
		}
		if(p1DidKO || p2DidKO) {
			this.status = GameStatus.RoundOver;
			StartCoroutine("DisplayTitleScreenAfterDelay",2.0f);
		}
	}
	
	private void CheckTimeout() {
		GameTimer timer = this.gameObject.GetComponent<GameTimer>();
		if(timer.timeLeft <= 0.0f) {
			this.status = GameRules.GameStatus.RoundOver;
			StartCoroutine("DisplayTitleScreenAfterDelay",2.0f);
		}
	}
	private IEnumerator BeginGameAfterDelay(float delaySeconds) {
		yield return new WaitForSeconds(delaySeconds);
		this.status = GameStatus.RoundPlaying;
	}
	private IEnumerator DisplayTitleScreenAfterDelay(float delaySeconds) {
		yield return new WaitForSeconds(delaySeconds);
		Application.LoadLevel("TitleScreen");
	}
}
